@@ -1204,11 +1204,15 @@ def init_conversions(remove_node_adding_conversions, ud_version):
         tokens=[
             Token(id="relativizer", spec=[Field(FieldNames.WORD, relativizing_words + list(relativizers_to_rel.keys()))]),
             Token(id="gov"),
-            Token(id="mod")
+            Token(id="mod"),
+            # a special case where we have an xcomp father for the head of the clause we attach the subj of the xcomp
+            #   e.g. "John is a man who like swimming", so "John" will become subj of like.
+            Token(id="grand", optional=True)
         ],
         edges=[
             Edge(child="mod", parent="gov", label=[HasLabelFromList(["acl:relcl"])]),  # TODO: english: relcl
-            Edge(child="relativizer", parent="mod", label=[HasLabelFromList(["/.*/"])])
+            Edge(child="relativizer", parent="mod", label=[HasLabelFromList(["/.*/"])]),
+            Edge(child="gov", parent="grand", label=[HasLabelFromList(["xcomp"])])
         ],
     )
 
@@ -1217,6 +1221,7 @@ def init_conversions(remove_node_adding_conversions, ud_version):
             gov = sentence[cur_match.token('gov')]
             mod = sentence[cur_match.token('mod')]
             relativizer = sentence[cur_match.token('relativizer')]
+            grand = cur_match.token('grand')
 
             # this is a pretty basic case so we can assume only one label
             label = list(cur_match.edge(cur_match.token('relativizer'), cur_match.token('mod')))[0]
@@ -1224,6 +1229,14 @@ def init_conversions(remove_node_adding_conversions, ud_version):
             # some relativizers that were simply missing on the eUD, we added them as nmods
             new_label = Label(udv(relativizers_to_rel[text]), eud=text if 1 == ud_version else "") if text in relativizers_to_rel else Label(label)
 
+            # for the special case we've added
+            if grand != -1:
+                grand = sentence[grand]
+                for child, rels in grand.get_children_with_rels():
+                    for rel in rels:
+                        if new_label.base == rel.base:
+                            child.add_edge(new_label, mod)
+
             reattach_children(relativizer, gov)
             relativizer.replace_edge(Label(label), Label("ref"), mod, gov)
             gov.add_edge(new_label, mod)
@@ -1548,7 +1561,7 @@ def remove_funcs(conversions, enhanced, enhanced_plus_plus, enhanced_extra, remo
             conversions.pop(func_name, None)
     if query_mode:
         for func_name in list(conversions.keys()):
-            if func_name in ['extra_nmod_advmod_reconstruction', 'extra_copula_reconstruction', 'extra_evidential_basic_reconstruction', 'extra_evidential_xcomp_reconstruction', 'extra_inner_weak_modifier_verb_reconstruction', 'extra_aspectual_reconstruction', 'eud_correct_subj_pass', 'eud_conj_info', 'eud_prep_patterns', 'eudpp_process_simple_2wp', 'eudpp_process_complex_2wp', 'eudpp_process_3wp', 'eudpp_demote_quantificational_modifiers']:
+            if func_name not in ['extra_nmod_advmod_reconstruction', 'extra_copula_reconstruction', 'extra_evidential_basic_reconstruction', 'extra_evidential_xcomp_reconstruction', 'extra_inner_weak_modifier_verb_reconstruction', 'extra_aspectual_reconstruction', 'eud_correct_subj_pass', 'eud_conj_info', 'eud_prep_patterns', 'eudpp_process_simple_2wp', 'eudpp_process_complex_2wp', 'eudpp_process_3wp', 'eudpp_demote_quantificational_modifiers']:
                 conversions.pop(func_name, None)
     if funcs_to_cancel:
         for func_to_cancel in funcs_to_cancel:
